==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGridActionStripContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebGridActionStripContentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridActionStripContentDescriptionMetadata, _super);
    function WebGridActionStripContentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridActionStripContentDescriptionMetadata.b = function (a) {
        if (WebGridActionStripContentDescriptionMetadata.a == null) {
            WebGridActionStripContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridActionStripContentDescriptionMetadata.c(WebGridActionStripContentDescriptionMetadata.a);
        }
        if (a.j(WebGridActionStripContentDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridActionStripContentDescriptionMetadata.a);
    };
    WebGridActionStripContentDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridActionStripContent");
        a.item("__tagNameWC", "String:igc-grid-action-strip-content");
        a.item("__manageCollectionInMarkup", "Boolean");
    };
    WebGridActionStripContentDescriptionMetadata.d = function (a) {
        WebGridActionStripContentDescriptionMetadata.b(a);
        a.z("WebGridActionStripContent", WebGridActionStripContentDescriptionMetadata.a);
    };
    WebGridActionStripContentDescriptionMetadata.$t = markType(WebGridActionStripContentDescriptionMetadata, 'WebGridActionStripContentDescriptionMetadata');
    WebGridActionStripContentDescriptionMetadata.a = null;
    return WebGridActionStripContentDescriptionMetadata;
}(Base));
export { WebGridActionStripContentDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridActionStripContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebGridActionStripContentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridActionStripContentDescriptionMetadata, _super);
    function WebGridActionStripContentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridActionStripContentDescriptionMetadata.b = function (a) {
        if (WebGridActionStripContentDescriptionMetadata.a == null) {
            WebGridActionStripContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridActionStripContentDescriptionMetadata.c(WebGridActionStripContentDescriptionMetadata.a);
        }
        if (a.k(WebGridActionStripContentDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridActionStripContentDescriptionMetadata.a);
    };
    WebGridActionStripContentDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridActionStripContent");
        a.item("__tagNameWC", "String:igc-grid-action-strip-content");
        a.item("__manageCollectionInMarkup", "Boolean");
    };
    WebGridActionStripContentDescriptionMetadata.d = function (a) {
        WebGridActionStripContentDescriptionMetadata.b(a);
        a.ab("WebGridActionStripContent", WebGridActionStripContentDescriptionMetadata.a);
    };
    WebGridActionStripContentDescriptionMetadata.$t = markType(WebGridActionStripContentDescriptionMetadata, 'WebGridActionStripContentDescriptionMetadata');
    WebGridActionStripContentDescriptionMetadata.a = null;
    return WebGridActionStripContentDescriptionMetadata;
}(Base));
export { WebGridActionStripContentDescriptionMetadata };
